import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { NgModule, NO_ERRORS_SCHEMA } from '@angular/core';
import { MDBBootstrapModule } from 'angular-bootstrap-md';
import { HttpModule } from '@angular/http';
import { FormsModule } from '@angular/forms'; // <-- NgModel lives here
//import { MdInputModule, MdDialogModule } from '@angular/material';
import { ChartModule } from 'angular2-chartjs';
import { RouterModule, Routes } from '@angular/router';
import { MarkdownModule } from 'ngx-md';

import { FormulaireService } from "./services/formulaire/formulaire.service";
import { ParamService } from "./services/param/param.service";
import { InternationalisationService } from "./services/internationalisation/internationalisation.service";
import { HttpService } from "./services/http/http.service";
import { ApplicationSetupService } from "./services/app-setup/app-setup.service";
import { AppComponent } from './app.component';
import { NgParamInputComponent } from './components/ngparam-input/ngparam-input.component';
import { FieldSetComponent } from './components/field-set/field-set.component';
import { FieldsetContainerComponent } from './components/fieldset-container/fieldset-container.component';
import { ParamFieldLineComponent } from './components/param-field-line/param-field-line.component';
import { NgParamMinComponent } from './components/param-values/ngparam-min.component';
import { NgParamMaxComponent } from './components/param-values/ngparam-max.component';
import { NgParamStepComponent } from './components/param-values/ngparam-step.component';
import { ParamValuesComponent } from './components/param-values/param-values.component';
import { ValueListComponent } from './components/param-values/value-list.component';
import { SelectFieldLineComponent } from './components/select-field-line/select-field-line.component';
import { CheckFieldLineComponent } from './components/check-field-line/check-field-line.component';
// import { AlertDialog } from './components/alert-dialog/alert-dialog.component';
import { AppErrorModule } from './error.module';
import { CalculatorResultsComponent } from './components/calculator-results/calculator-results.component';
import { FixedVarResultsComponent } from './components/fixedvar-results/fixedvar-results.component';
import { SectionResultsComponent } from './components/section-results/section-results.component';
import { GenericCalculatorComponent } from './components/generic-calculator/calculator.component';
import { CalculatorNameComponent } from './components/generic-calculator/calc-name.component';
import { CalcCanvasComponent } from './components/canvas/canvas.component';
import { SectionCanvasComponent } from './components/section-canvas/section-canvas.component';
import { RemousResultsComponent } from './components/remous-results/remous-results.component';
import { ResultsGraphComponent } from './components/results-graph/results-graph.component';
import { GraphTypeSelectComponent } from './components/results-graph/graph-type.component';
import { LogComponent } from './components/log/log.component';
import { CalculatorListComponent } from './components/calculator-list/calculator-list.component';
import { ApplicationSetupComponent } from './components/app-setup/app-setup.component';
import { BaseParamInputComponent } from './components/base-param-input/base-param-input.component';
import { FixedResultsComponent } from './components/fixedvar-results/fixed-results.component';
import { VarResultsComponent } from './components/fixedvar-results/var-results.component';
import { HorizontalResultElementComponent } from './components/result-element/horizontal-result-element.component'
import { VerticalResultElementComponent } from './components/result-element/vertical-result-element.component';
import { LogEntryComponent } from './components/log-entry/log-entry.component';
import { HelpService } from './services/help/help.service';
import { HelpComponent } from './components/help/help.component';
import { LoadCalculatorComponent } from './components/load-calculator/load-calculator.component';
import { LoadCalcDialogAnchorDirective } from './components/load-calculator/load-calculator-anchor.directive';
import { SaveCalculatorComponent } from './components/save-calculator/save-calculator.component';
import { SaveCalcDialogAnchorDirective } from './components/save-calculator/save-calculator-anchor.directive';

const appRoutes: Routes = [
  { path: 'list', component: CalculatorListComponent },
  { path: 'calculator/:uid', component: GenericCalculatorComponent },
  { path: 'setup', component: ApplicationSetupComponent },
  { path: 'help', component: HelpComponent },
  { path: '**', component: CalculatorListComponent }
];

@NgModule({
  imports: [
    RouterModule.forRoot(
      appRoutes,
      //{ enableTracing: true } // <-- debugging purposes only
      { enableTracing: false }
    ),
    BrowserModule,
    MarkdownModule.forRoot(),
    BrowserAnimationsModule,
    MDBBootstrapModule.forRoot(),
    FormsModule, // <-- import the FormsModule before binding with [(ngModel)]
    HttpModule,
    // MdInputModule,
    // MdDialogModule,
    ChartModule,
    AppErrorModule
  ],
  declarations: [ // composants, pipes et directives
    AppComponent,
    NgParamInputComponent,
    FieldSetComponent, FieldsetContainerComponent,
    ParamFieldLineComponent, NgParamMinComponent, NgParamMaxComponent, NgParamStepComponent,
    ParamValuesComponent, ValueListComponent,
    SelectFieldLineComponent, CheckFieldLineComponent,
    LogComponent, LogEntryComponent,
    CalculatorListComponent,
    ApplicationSetupComponent,
    BaseParamInputComponent,
    GenericCalculatorComponent, CalculatorNameComponent,
    // AlertDialog,
    CalculatorResultsComponent, FixedVarResultsComponent, SectionResultsComponent, RemousResultsComponent,
    ResultsGraphComponent, GraphTypeSelectComponent,
    CalcCanvasComponent, SectionCanvasComponent,
    HorizontalResultElementComponent, VerticalResultElementComponent,
    FixedResultsComponent, VarResultsComponent,
    HelpComponent,
    LoadCalculatorComponent, LoadCalcDialogAnchorDirective,
    SaveCalculatorComponent, SaveCalcDialogAnchorDirective
  ],
  // entryComponents: [AlertDialog],
  entryComponents: [LoadCalculatorComponent, SaveCalculatorComponent],
  providers: [ // services
    ParamService, InternationalisationService, HttpService, FormulaireService, ApplicationSetupService, HelpService
  ],
  schemas: [NO_ERRORS_SCHEMA],
  bootstrap: [AppComponent]
})
export class AppModule { }
