import { Component, ViewChild } from "@angular/core";

import { BaseParam, ParamDomainValue, Observer } from "jalhyd";

import { ApplicationSetupService } from '../../services/app-setup/app-setup.service';
import { InternationalisationService, Language, LanguageCode } from '../../services/internationalisation/internationalisation.service';
import { NgBaseParam, BaseParamInputComponent } from "../base-param-input/base-param-input.component";
import { BaseComponent } from "../base/base.component";

@Component({
    selector: "setup",
    templateUrl: "./app-setup.component.html",
})
export class ApplicationSetupComponent extends BaseComponent implements Observer {
    /**
     * précision d'affichage
     */
    private _displayPrec: NgBaseParam;

    /**
     * précision de calcul
     */
    private _computePrec: NgBaseParam;

    /**
     * nombre d'iterations max Newton
     */
    private _newtonMaxIter: NgBaseParam;

    @ViewChild("displayAccurary")
    private _displayAccuraryComponent: BaseParamInputComponent;

    @ViewChild("computeAccuracy")
    private _computeAccuraryComponent: BaseParamInputComponent;

    @ViewChild("newtonMaxIter")
    private _newtonMaxIterComponent: BaseParamInputComponent;

    constructor(
        private appSetupService: ApplicationSetupService,
        private intlService: InternationalisationService
    ) {
        super();
    }

    private get currentLanguageLabel(): string {
        return this.intlService.currentLanguage.label;
    }

    private selectLang(lc: LanguageCode) {
        this.intlService.setLocale(lc);
    }

    private get uitextTitle(): string {
        return this.intlService.localizeText("INFO_SETUP_TITLE");
    }

    private get uitextDisplayAccuracy(): string {
        return this.intlService.localizeText("INFO_SETUP_PRECISION_AFFICHAGE");
    }

    private get uitextComputeAccuracy(): string {
        return this.intlService.localizeText("INFO_SETUP_PRECISION_CALCUL");
    }

    private get uitextNewtonMaxIteration(): string {
        return this.intlService.localizeText("INFO_SETUP_NEWTON_MAX_ITER");
    }

    private init() {
        // modèle du composant BaseParamInputComponent de précision d'affichage
        this._displayPrec = new NgBaseParam("dp", ParamDomainValue.POS, this.appSetupService.displayPrecision);
        this._displayPrec.addObserver(this);
        this._displayAccuraryComponent.model = this._displayPrec;

        // modèle du composant BaseParamInputComponent de précision de calcul
        this._computePrec = new NgBaseParam("cp", ParamDomainValue.POS, this.appSetupService.computePrecision);
        this._computePrec.addObserver(this);
        this._computeAccuraryComponent.model = this._computePrec;

        // modèle du composant BaseParamInputComponent du max d'itérations pour Newton
        this._newtonMaxIter = new NgBaseParam("nmi", ParamDomainValue.POS, this.appSetupService.newtonMaxIter);
        this._newtonMaxIter.addObserver(this);
        this._newtonMaxIterComponent.model = this._newtonMaxIter;
    }

    /**
     * appelé une fois, après l'affichage complet du composant
     */
    protected afterFirstViewChecked() {
        this.init();
    }

    // interface Observer

    public update(sender: any, data: any): void {
        const p: NgBaseParam = sender;
        switch (p.symbol) {
            case "dp":
                this.appSetupService.displayPrecision = +data;
                break;

            case "cp":
                this.appSetupService.computePrecision = +data;
                break;

            case "nmi":
                this.appSetupService.newtonMaxIter = +data;
                break;
        }
    }
}
