import { Component, Output, EventEmitter } from "@angular/core";
import { BaseComponent } from "../base/base.component";

/*
  exemple de template :

<div class="btn-group" dropdown (click)="onSelect($event)">
    <button dropdownToggle class="btn btn-primary dropdown-toggle waves-light my-1" type="button" mdbRippleRadius>
        {{currentLabel}}
    </button>
    <div class="dropdown-menu">
        <a class="dropdown-item" *ngFor="let e of entries" [value]=e>{{entryLabel(e)}}</a>
    </div>
</div>
*/

export abstract class GenericSelectComponent<T> {
    private get currentLabel(): string {
        for (let e of this.entries)
            if (e == this.selectedValue)
                return this.entryLabel(e);

        return "<no selection>";
    }

    /**
     * appelé quand la valeur courante change dans l'UI
     */
    private onSelect(event: any) {
        const val = event.target.value;
        if (val != undefined)
            this.selectedValue = val;
    }

    /**
     * liste des objets sélectionnables
     */
    protected abstract get entries(): any[];

    /**
     * calcule l'étiquette d'une entrée (ce qui est affiché dans la liste déroulante)
     */
    protected abstract entryLabel(entry: any): string;

    /**
     *  valeur actuellement sélectionnée
     * la valeur repère une entrée de la liste (cf. [value] dans le template)
     */
    public abstract get selectedValue(): T;


    public abstract set selectedValue(v: T);
}
