import { Component, Input, OnChanges } from "@angular/core";

import { Message, MessageSeverity } from 'jalhyd';

import { InternationalisationService } from "../../services/internationalisation/internationalisation.service";
import { ApplicationSetupService } from '../../services/app-setup/app-setup.service';

@Component({
    selector: "log-entry",
    templateUrl: "./log-entry.component.html",
    styles: [`
        .entry {
            margin-left: 1em;
            margin-right: 1em;
            margin-top: 0.5em;
            margin-bottom: 0.5em;
        }
    `]

})
export class LogEntryComponent implements OnChanges {
    @Input("message")
    private _message: Message;

    /**
     * message mis en forme
     */
    private _text: string;

    constructor(
        private intlService: InternationalisationService,
        private appSetupService: ApplicationSetupService
    ) { }

    /**
     * appelé quand les @Input changent
     */
    ngOnChanges() {
        this.updateText();
    }

    private updateText() {
        const nDigits = this.appSetupService.displayDigits;
        this._text = this.intlService.localizeMessage(this._message, nDigits);
    }

    private get text(): string {
        return this._text;
    }

    private get levelInfo(): boolean {
        return this._message.getSeverity() == MessageSeverity.INFO;
    }

    private get levelWarning(): boolean {
        return this._message.getSeverity() == MessageSeverity.WARNING;
    }

    private get levelError(): boolean {
        return this._message.getSeverity() == MessageSeverity.ERROR;
    }
}
