import { Component, ViewChild, AfterContentInit } from '@angular/core';

import { Observer } from "jalhyd";

import { VarResults, GraphType } from "../../results/var-results";
import { GraphTypeSelectComponent } from './graph-type.component';

@Component({
    selector: 'results-graph',
    templateUrl: './results-graph.component.html'
})
export class ResultsGraphComponent implements AfterContentInit, Observer {
    private _results: VarResults;

    @ViewChild(GraphTypeSelectComponent)
    private _graphTypeComponent: GraphTypeSelectComponent;

    /*
     * config du graphe
     */
    private graph_type: string;
    private graph_data = {};
    private graph_options = {
        responsive: true,
        maintainAspectRatio: true,
        animation: {
            duration: 0
        },
        legend: {
            display: false
        },
        title: {
            display: true,
            text: ""
        }
    };

    public set results(r: VarResults) {
        this._results = r;
        if (this._results && this._graphTypeComponent)
            this._graphTypeComponent.selectedValue = r.graphType;
    }

    public updateView() {
        switch (this._graphTypeComponent.selectedValue) {
            case GraphType.Histogram:
                this.graph_type = "bar";
                this.generateBarGraph();
                break;

            case GraphType.HistoLine:
                this.graph_type = "line";
                this.generateLineGraph();
                break;

            default:
                this.graph_type = "scatter";
                this.generateScatterGraph();
                break;
        }
    }

    public ngAfterContentInit() {
        this._graphTypeComponent.addObserver(this);
    }

    /**
     * génère les données d'un graphe de type "line"
     */
    private generateLineGraph() {
        let labs = [];
        let dat = [];
        let i = 0;
        for (const x of this._results.variatedParameter.valuesIterator) {
            labs.push(String(x));

            const y = this._results.yValues[i];
            dat.push(y);
            i++;
        }

        this.graph_options.title.text = this._results.graphTitle;

        this.graph_data = {
            labels: labs,
            datasets: [
                {
                    label: "",
                    data: dat
                }
            ]
        };
    }

    /**
     * génère les données d'un graphe de type "bar"
     */
    private generateBarGraph() {
        let labs = [];
        let dat = [];
        let i = 0;
        for (const x of this._results.variatedParameter.valuesIterator) {
            labs.push(x);

            const y = this._results.yValues[i];
            dat.push(y);

            i++;
        }

        this.graph_options.title.text = this._results.graphTitle;
        this.graph_options["scales"] = {
            xAxes: [{
                gridLines: {
                    offsetGridLines: true
                }
            }]
        };

        this.graph_data = {
            labels: labs,
            datasets: [
                {
                    label: "",
                    data: dat
                }
            ]
        };
    }

    /**
     * génère les données d'un graphe de type "scatter"
     */
    private generateScatterGraph() {
        let dat = [];
        let i = 0;
        for (const x of this._results.variatedParameter.valuesIterator) {
            const y = this._results.yValues[i];
            dat.push({ x: x, y: y });
            i++;
        }

        this.graph_options.title.text = this._results.graphTitle;
        this.graph_options["scales"] = {
            xAxes: [{
                type: 'linear',
                position: 'bottom'
            }],
            yAxes: [{
                type: 'linear',
                position: 'left'
            }]
        };

        this.graph_data = {
            datasets: [
                {
                    label: "",
                    data: dat,
                    borderColor: "#808080", // couleur de la ligne
                    backgroundColor: "rgba(0,0,0,0)",  // couleur de remplissage sous la courbe : transparent
                    showLine: "true"
                }
            ]
        };
    }

    // interface Observer 

    update(sender: any, data: any) {
        this.updateView();
    }
}
