import { Component, EventEmitter } from "@angular/core";
import { ServiceFactory } from "../../services/service-factory";
import { InternationalisationService } from "../../services/internationalisation/internationalisation.service";

@Component({
    selector: 'save-calc',
    templateUrl: "./save-calculator.component.html"
})
export class SaveCalculatorComponent {
    /**
     * liste des calculettes affichées. Forme des objets :
     * "title": nom de la calculette
     * "selected": flag de sélection pour la sauvegarde
     * "uid": id unique du formulaire
     */
    private _calculators: any[];

    /**
     * nom du fichier
     */
    private _filename: string = "session";

    private _filenameTitle = "Nom de fichier";

    /**
     * événement émis lors du clic sur "annuler"/"enregister"
     * utilisé par la promise de gestion de la confirmation/annulation de la sauvegarde
     */
    private confirmResult = new EventEmitter();

    // services
    private intlService: InternationalisationService;

    constructor() {
        this.intlService = ServiceFactory.instance.internationalisationService;
    }

    private get uitextDialogTitle() {
        return "Enregister les calculettes";
    }

    private get uitextCloseDialogYes() {
        //return this.intlService.localizeText("INFO_OPTION_YES");
        return "Sauver";
    }

    private get uitextCloseDialogNo() {
        // return this.intlService.localizeText("INFO_OPTION_NO");
        return "Annuler";
    }

    private get uitextSelectAll() {
        return "Toutes";
    }

    private get uitextDeselectAll() {
        return "Aucune";
    }

    public get filename(): string {
        return this._filename;
    }

    public run(calcList: any[]): Promise<any[]> {
        this._calculators = calcList;

        // promise de gestion de la confirmation/annulation de la sauvegarde
        return new Promise((resolve, reject) => {
            this.confirmResult.subscribe((confirm) => {
                if (confirm) {
                    resolve(this._calculators);
                } else {
                    reject();
                }
            });
        });
    }

    private isSelected(c: any) {
        return c.selected ? "checked" : undefined;
    }

    private onCheckCalc(event: any) {
        for (const c of this._calculators)
            if (c.uid == +event.target.value)
                c.selected = event.target.checked;
    }

    private selectAll() {
        for (const c of this._calculators)
            c.selected = true;
    }

    private deselectAll() {
        for (const c of this._calculators)
            c.selected = false;
    }

    private set confirmed(b: boolean) {
        setTimeout(() => {
            this.confirmResult.next(b);
        }, 0);
    }

    /**
     * appelé quand on clique sur annuler
     */
    private cancelSave() {
        this.confirmed = false;
    }

    /**
     * appelé quand on clique sur sauver
     */
    private confirmSave() {
        this.confirmed = true;
    }
}
