import { CalculatorType, ComputeNodeType, IObservable } from "jalhyd";

import { FormResultRemous } from "../form-result-remous";
import { FormDefSection } from "../form-def-section";
import { FormComputeCourbeRemous } from "../form-compute-courbe-remous";
import { FormulaireDefinition } from "../form-definition";
import { CalculatorResults } from "../../../results/calculator-results";
import { FieldSet } from "../../fieldset";
import { SelectField } from "../../select-field";

export class FormulaireCourbeRemous extends FormulaireDefinition {
    private _formSection: FormDefSection;

    private _formCompute: FormComputeCourbeRemous;

    private _formResult: FormResultRemous;

    /**
     * id du select configurant la méthode de résolution
     */
    private _resolveMethSelectId: string;

    constructor() {
        super();
        this._formSection = new FormDefSection(this);
        this._formResult = new FormResultRemous(this);
        this._formCompute = new FormComputeCourbeRemous(this, this._formSection, this._formResult);
    }

    protected get defaultProperties(): {} {
        return { "calcType": CalculatorType.CourbeRemous, "nodeType": ComputeNodeType.SectionPuissance };
    }

    protected parseOptions(json: {}) {
        this._formSection.parseOptions(json);

        // id du select configurant la méthode de résolution
        this._resolveMethSelectId = this.getOption(json, "methodSelectId");
    }

    public afterParseFieldset(fs: FieldSet) {
        this._formSection.afterParseFieldset(fs);

        // si le FieldSet contient le select de méthode de résolution
        if (this._resolveMethSelectId) {
            const sel = fs.getFormulaireNodeById(this._resolveMethSelectId);
            if (sel) {
                // on abonne le formulaire aux propriétés du FieldSet
                fs.properties.addObserver(this);
            }
        }
    }

    public resetResults() {
        this._formResult.resetResults();
    }

    public doCompute() {
        this._formCompute.doCompute();
    }

    public get hasResults(): boolean {
        return this._formResult.hasResults;
    }

    public get results(): CalculatorResults[] {
        return this._formResult.results;
    }

    // interface Observer

    update(sender: IObservable, data: any) {
        if (sender instanceof FieldSet && data.action == "propertyChange") {
            switch (sender.id) {
                case "fs_section":
                    this.replaceCurrentSessionNub(sender.properties);
                    for (const fs of this.allFieldsets)
                        fs.setSessionNub(this._currentSessionNub);
                    this.reset();
                    break;

                case "fs_param_calc":
                case "fs_target_data":
                    this.reset();
                    break;
            }
        }
    }
}
