import { CalculatorType, ComputeNodeType, Observer } from "jalhyd";

import { FormResultFixedVar } from "../form-result-fixedvar";
import { FormDefFixedVar } from "../form-def-fixedvar";
import { FormulaireDefinition } from "../form-definition";
import { CalculatorResults } from "../../../results/calculator-results";
import { FormDefParamToCalculate } from "../form-def-paramcalc";
import { SelectField } from "../../select-field";
import { FormComputeFixedVar } from "../form-compute-fixedvar";

export class FormulaireLechaptCalmon extends FormulaireDefinition implements Observer {
    private _formFixedVar: FormDefFixedVar;

    private _formParamCalc: FormDefParamToCalculate;

    private _formCompute: FormComputeFixedVar;

    private _formResult: FormResultFixedVar;

    constructor() {
        super();
        this._formFixedVar = new FormDefFixedVar(this);
        this._formParamCalc = new FormDefParamToCalculate(this);
        this._formResult = new FormResultFixedVar(this, false);
        this._formCompute = new FormComputeFixedVar(this, this._formResult);
    }

    protected get defaultProperties(): {} {
        return { "calcType": CalculatorType.LechaptCalmon, "nodeType": ComputeNodeType.None };
    }

    protected initParse() {
        this._formParamCalc.initParse();
    }

    protected completeParse(json: {}) {
        this._formParamCalc.parseOptions(json);
        // abonnement au changement de valeur du select de matériau
        this.getFormulaireNodeById("select_material").addObserver(this);
    }

    /**
     * gestion du clic sur les radios "paramètre fixé, à varier, à calculer"    
     */
    public onRadioClick(info: string) {
        super.onRadioClick(info);
        this._formParamCalc.onRadioClick(info);
    }

    public resetResults() {
        this._formResult.resetResults();
    }

    public doCompute() {
        this._formCompute.doCompute();
    }

    public get hasResults(): boolean {
        return this._formResult.hasResults;
    }

    public get results(): CalculatorResults[] {
        return this._formResult.results;
    }

    // interface Observer

    public update(sender: any, data: any) {
        // en cas de changement de valeur du select de matériau, effacement des résultats et MAJ des champs L,M,N
        if (sender instanceof SelectField) {
            if (data.action == "select")
                this.reset();
        }
    }
}
