import { CalculatorType, ComputeNodeType } from "jalhyd";

import { CalculatorResults } from "../../../results/calculator-results";
import { FormulaireDefinition } from "../form-definition";
import { FormDefFixedVar } from "../form-def-fixedvar";
import { FormDefParamToCalculate } from "../form-def-paramcalc";
import { FormResultFixedVar } from "../form-result-fixedvar";
import { FormComputeFixedVar } from "../form-compute-fixedvar";

export class FormulairePasseBassinDimensions extends FormulaireDefinition {
    private _formFixedVar: FormDefFixedVar;

    private _formParamCalc: FormDefParamToCalculate;

    private _formCompute: FormComputeFixedVar;

    private _formResult: FormResultFixedVar;

    constructor() {
        super();
        this._formFixedVar = new FormDefFixedVar(this);
        this._formParamCalc = new FormDefParamToCalculate(this);
        this._formResult = new FormResultFixedVar(this, false);
        this._formCompute = new FormComputeFixedVar(this, this._formResult);
    }

    protected get defaultProperties(): {} {
        return { "calcType": CalculatorType.PabDimensions, "nodeType": ComputeNodeType.None };
    }

    protected initParse() {
        this._formParamCalc.initParse();
    }

    protected completeParse(json: {}) {
        this._formParamCalc.parseOptions(json);
    }

    /**
     * gestion du clic sur les radios "paramètre fixé, à varier, à calculer"    
     */
    public onRadioClick(info: string) {
        super.onRadioClick(info);
        this._formParamCalc.onRadioClick(info);
    }

    public resetResults() {
        this._formResult.resetResults();
    }

    public doCompute() {
        this._formCompute.doCompute();
    }

    public get hasResults(): boolean {
        return this._formResult.hasResults;
    }

    public get results(): CalculatorResults[] {
        return this._formResult.results;
    }
}
