import { SectionParametree, acSection, ParamsEquation, ComputeNode, Result, MethodeResolution, CourbeRemousParams, CourbeRemous, ResultElement, ParamValues, CalculatorType } from "jalhyd";

import { SelectField } from "../select-field";
import { RemousResults } from "../../results/remous-results";
import { FormulaireDefinition } from "./form-definition";
import { FormDefSection } from "./form-def-section";
import { FormCompute } from "./form-compute";
import { FormResultRemous } from "./form-result-remous";

export class FormComputeCourbeRemous extends FormCompute {
    constructor(formBase: FormulaireDefinition, private _formSection: FormDefSection, formResult: FormResultRemous) {
        super(formBase, formResult);
    }

    private get remousResults(): RemousResults {
        const f = this._formResult as FormResultRemous;
        return f.remousResults;
    }

    protected compute() {
        const cr: CourbeRemous = this._formBase.currentSessionNub.nub as CourbeRemous;
        const prmCR: CourbeRemousParams = cr.parameters as CourbeRemousParams;
        const sect: acSection = prmCR.Sn;

        let Yn: Result = sect.Calc("Yn"); // hauteur normale
        let Yc: Result = sect.Calc("Yc"); // hauteur critique

        this.remousResults.parameters = prmCR;

        // méthode de résolution

        let msf: SelectField = <SelectField>this._formBase.getFormulaireNodeById("select_resolution");
        let methRes: MethodeResolution = msf.getValue().value;

        // variable supplémentaire à calculer

        const extraSymbol: string = this._formBase.getSelectedValue("select_target");

        // calcul

        this.remousResults.result = cr.calculRemous(extraSymbol);

        // données du graphe

        this.remousResults.hauteurNormale = Yn.resultElement;
        this.remousResults.hauteurCritique = Yc.resultElement;
        if (extraSymbol) {
            this.remousResults.extraParamLabel = this._formBase.getSelectedLabel("select_target");
            this.remousResults.extraGraph = ["Hs", "Hsc", "Yf", "Yt", "Yco"].indexOf(extraSymbol) == -1;
        }
        else
            this.remousResults.extraGraph = false;
    }
}
