import { ParamValueMode } from "jalhyd";

import { ParamRadioConfig, NgParameter } from "../ngparam";
import { FormulaireDefinition } from "./form-definition";
import { FormulaireElement } from "../formulaire-element";
import { InputField } from "../input-field";
import { CheckField } from "../check-field";

/**
 * gestion des formulaires avec "paramètre fixé" et "paramètre à varier"
 */
export class FormDefFixedVar {
    protected _formBase: FormulaireDefinition;

    constructor(base: FormulaireDefinition) {
        this._formBase = base;
    }

    /**
     * remet les radios de tous les paramètres à FIX sauf "me" et ceux (celui) à l'état "except"
     */
    protected resetOtherRadio(me: NgParameter, except: ParamRadioConfig) {
        for (const p of this._formBase.allFormElements) {
            if (p instanceof NgParameter)
                if (p != me && p.radioState != except && p.radioConfig != ParamRadioConfig.FIX)
                    p.valueMode = ParamValueMode.SINGLE;
        }
    }

    protected processRadioStateChange(sourceParam: NgParameter, oldState: ParamValueMode) {
        switch (oldState) {
            case ParamValueMode.SINGLE:
                switch (sourceParam.valueMode) { // nouvel état
                    case ParamValueMode.MINMAX:
                    case ParamValueMode.LISTE:
                        this.resetOtherRadio(sourceParam, ParamRadioConfig.CAL);
                        break;

                    case ParamValueMode.CALCUL:
                        this.resetOtherRadio(sourceParam, ParamRadioConfig.VAR);
                        break;
                }
                break;

            case ParamValueMode.LISTE:
            case ParamValueMode.MINMAX:
                switch (sourceParam.valueMode) { // nouvel état
                    case ParamValueMode.CALCUL:
                        this.resetOtherRadio(sourceParam, ParamRadioConfig.VAR);
                        break;
                }
                break;
        }
    }

    /**
     * modifie les boutons radio "fix", "var", "cal" de tous les paramètres
     * en fonction de la modification de l'état d'un des paramètres
     * @param uid id numérique unique du paramètre source
     * @param option nouvel état "fix", "var" ou "cal" du paramètre source
     */
    protected resetRadiosAndResults(sourceParam: NgParameter, oldState: ParamValueMode) {
        this.processRadioStateChange(sourceParam, oldState);

        // on vérifie qu'il y a au moins un paramètre "à calculer" et sinon, on prend le 1er qui est à "fixé"
        if (this._formBase.getDisplayedParamFromState(ParamRadioConfig.CAL) == undefined) {
            let newCal: NgParameter = undefined;

            for (const p of this._formBase.allFormElements) {
                if (p instanceof NgParameter)
                    if (p.radioConfig == ParamRadioConfig.CAL && p.radioState == ParamRadioConfig.FIX && p != sourceParam) {
                        newCal = p;
                        break;
                    }
                if (newCal != undefined)
                    break;
            }

            if (newCal != undefined)
                newCal.valueMode = ParamValueMode.CALCUL;
        }
    }

    /**
     * gestion des événements clic sur les radios
     */
    public onRadioClick(info: any) {
        const param: NgParameter = info.param; // paramètre source de l'événement radio
        const old: ParamValueMode = info.oldValueMode; // ancien état (radio)

        this.resetRadiosAndResults(param, old);
    }
}
