import { CalculatorType, StructureType, LoiDebit } from "jalhyd";

import { FieldSet } from "../fieldset";

/**
 * gestion des formulaires "ouvrages parallèles"
 */
export class FormDefParallelStructures {
    /**
     * dictionnaire des types d'ouvrages indexés par les valeurs de liste déroulante
     * la clé est la chaîne utilisée dans le fichier de configuration de la calculette pour les valeurs de la liste déroulante
     */
    private static tsMap = {
        "vanne_rect": StructureType.VanneRectangulaire,
        "seuil_rect": StructureType.SeuilRectangulaire
    }

    /**
     * dictionnaire des LoiDebit indexés par les valeurs de liste déroulante
     * la clé est la chaîne utilisée dans le fichier de configuration de la calculette pour les valeurs de la liste déroulante
     */
    private static ldMap = {
        "cem88d": LoiDebit.Cem88d,
        "cem88v": LoiDebit.Cem88d,
        "cunge80": LoiDebit.Cunge80,
        "seuildenoye": LoiDebit.WeirFree,
        "vannenoye": LoiDebit.OrificeSubmerged,
        "vannedenoye": LoiDebit.OrificeFree,
        "kivi": LoiDebit.KIVI
    }

    /**
     * @return type d'ouvrage courant du FieldSet donné
     */
    public getStructureType(fs: FieldSet): StructureType {
        let structType: string = fs.getSelectedValue("select_ouvrage");
        if (structType == undefined)
            throw new Error(`FormDefParallelStructures.getStructureType() : aucun ouvrage trouvé dans le FieldSet`);

        const res = FormDefParallelStructures.tsMap[structType];
        if (res == undefined)
            throw new Error(`FormDefParallelStructures.getStructureType() : type d'ouvrage ${StructureType[structType]} non pris en charge`);
        return res;
    }

    /**
     * @return loi de débit courante du FieldSet donné
     */
    public getLoiDebit(fs: FieldSet): LoiDebit {
        let loiDebit: string = fs.getSelectedValue("select_loidebit1");
        if (loiDebit == undefined)
            loiDebit = fs.getSelectedValue("select_loidebit2");
        if (loiDebit == undefined)
            throw new Error(`FormDefParallelStructures.getStructureType() : aucune loi de débit trouvée dans le FieldSet`);

        const res = FormDefParallelStructures.ldMap[loiDebit];
        if (res == undefined)
            throw new Error(`FormDefParallelStructures.getStructureType() : loi de débit ${LoiDebit[loiDebit]} non prise en charge`);
        return res;
    }
}
