import { ParamValueMode } from "jalhyd";

import { ParamRadioConfig, NgParameter } from "../ngparam";
import { FormulaireDefinition } from "./form-definition";
import { FormDefFixedVar } from "./form-def-fixedvar";
import { NgParamInputComponent } from "../../components/ngparam-input/ngparam-input.component";

/** 
 * gestion des formulaires avec "paramètre à calculer" (conduite distributrice, Lechapt-Calmon, régime uniforme, passes à bassin)
 */
export class FormDefParamToCalculate extends FormDefFixedVar {
    /**
     * symbole du paramètre à calculer par défaut (cf config "idCal")
     */
    private _defaultCalculatedParam: string;

    constructor(base: FormulaireDefinition) {
        super(base);
    }

    public initParse() {
        this._defaultCalculatedParam = undefined;
    }

    public parseOptions(json: {}) {
        for (const k in json) {
            const o = json[k];
            if (o.type === "options") {
                // id du paramètre à calculer par défaut

                this._defaultCalculatedParam = o["idCal"];
                if (this._defaultCalculatedParam != undefined) {
                    const p = this.setDefault();
                    p.isDefault = true;
                }
            }
        }
    }

    /**
     * met le paramètre par défaut à CAL
     */
    private setDefault(): NgParameter {
        const defaultParamCal: NgParameter = this._formBase.getParamFromSymbol(this._defaultCalculatedParam);
        defaultParamCal.valueMode = ParamValueMode.CALCUL;
        return defaultParamCal;
    }

    protected processRadioStateChange(sourceParam: NgParameter, oldState: ParamValueMode) {
        super.processRadioStateChange(sourceParam, oldState);

        switch (oldState) {
            case ParamValueMode.CALCUL:
                switch (sourceParam.valueMode) {  // nouvel état
                    case ParamValueMode.SINGLE:
                        this.setDefault();
                        break;

                    case ParamValueMode.MINMAX:
                    case ParamValueMode.LISTE:
                        super.resetOtherRadio(sourceParam, ParamRadioConfig.CAL);
                        this.setDefault();
                        break;
                }
        }
    }
}
