import { Injectable } from '@angular/core';
import { Http, RequestOptions, RequestOptionsArgs, Headers, Response } from '@angular/http';
import { Observable } from "rxjs/Observable";
import 'rxjs/add/operator/map';
import { StringMap } from '../../stringmap';

@Injectable()
export class HttpService {
    constructor(private http: Http) { }

    private concat(s1: string, s2: string): string {
        if (s1 == undefined)
            return s2;

        if (s2 == undefined)
            return s1;

        return s1 + s2;
    }

    public httpGetRequest(protocol: string, host: string, port: number, path: string,
        processDataCallback: (s: string) => void,
        errorCallback?: (err: any) => void,
        headers?: StringMap): Promise<Response> {
        let resp: Observable<Response> = this.httpGetRequestResponse(protocol, host, port, path);

        resp.map(res => res.text())
            .subscribe(
                data => processDataCallback(data),
                err => { if (errorCallback) errorCallback(err) },
            //            () => console.log('Random Quote Complete')
        );

        return resp.toPromise();
    }

    public httpGetRequestResponse(protocol: string, host: string, port: number, path: string, headers?: StringMap): Observable<Response> {
        let url: string;
        if (protocol != undefined)
            url = protocol + "://" + host;
        else if (host != undefined)
            url = host;

        if (port != undefined)
            url = this.concat(url, ":" + String(port));

        let p = path === "/" ? "" : path;
        if (url == undefined)
            url = p;
        else
            url = this.concat(url, "/" + p);

        let enc = encodeURI(url);

        let opts = new RequestOptions();
        if (headers) {
            const hds = new Headers();
            for (const k in headers)
                hds.append(k, headers[k]);
            opts.headers = hds;
        }

        let res: Observable<Response> = this.http.get(enc, opts);
        return res;
    }
}
